pub struct RunDeploymentPreparation;Trait Implementations
Sourceimpl GraphQLQuery for RunDeploymentPreparation
impl GraphQLQuery for RunDeploymentPreparation
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for RunDeploymentPreparation
impl RefUnwindSafe for RunDeploymentPreparation
impl Send for RunDeploymentPreparation
impl Sync for RunDeploymentPreparation
impl Unpin for RunDeploymentPreparation
impl UnsafeUnpin for RunDeploymentPreparation
impl UnwindSafe for RunDeploymentPreparation